package fr.iutlille.ctp_2025;

import static android.media.CamcorderProfile.get;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.DividerItemDecoration;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import android.os.Bundle;
import android.view.ContextMenu;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Button;

import java.util.ArrayList;
import java.util.List;

import fr.iutlille.ctp_2025.databinding.ActivityMainBinding;

public class MainActivity extends AppCompatActivity {

    public class ParticipantAdapter extends RecyclerView.Adapter<ParticipantViewHolder> {

        private List<Participant> participantsList;
        public static final int MENU_DELETE = 1;
        private AdapterView.OnItemClickListener listener;


        ParticipantAdapter(){}

        public ParticipantAdapter(List<Participant> participants) {
            this.participantsList = participants;
        }

        @NonNull
        @Override
        public ParticipantViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
            View itemView = LayoutInflater.from(parent.getContext())
                    .inflate(android.R.layout.simple_list_item_2, parent, false);
            return new ParticipantViewHolder(itemView);
        }

        @Override
        public void onBindViewHolder(@NonNull ParticipantViewHolder holder, int position) {
            Participant participant = model.getParticipant(position);
            holder.text1.setText(participant.getName());
            holder.text2.setText(participant.getName());

        }

        @Override
        public int getItemCount() {
            return model.getNbParticipants();
        }
    }
    public class ParticipantViewHolder extends RecyclerView.ViewHolder {

        TextView text1;
        TextView text2;
        public static final int MENU_DELETE = 1;

        private AdapterView.OnItemClickListener listener;

        public ParticipantViewHolder(View itemView) {
            super(itemView);
            text1 = itemView.findViewById(android.R.id.text1);
            text2 = itemView.findViewById(android.R.id.text2);
            itemView.setOnCreateContextMenuListener(this::onCreateContextMenu);
        }

        public void onClick(View v) {
            if (listener != null)
                listener.onItemClick(getAbsoluteAdapterPosition());
        }

        private void onCreateContextMenu(ContextMenu menu,
                                         View v,
                                         ContextMenu.ContextMenuInfo menuInfo){
            int position = getAbsoluteAdapterPosition();
            menu.add(Menu.NONE, MENU_DELETE, position, "Delete");
            menu.setHeaderTitle(ui.ParticipantList.toString());
        }

        private int getAbsoluteAdapterPosition() {
        }

        public void setOnItemClickListener(AdapterView.OnItemClickListener l) {
            this.listener = l;
        }

        public void onBindViewHolder(@NonNull ParticipantViewHolder holder, int position) {
            Participant participant = model.getParticipant(position);
            holder.setOnItemClickListener(listener);
        }}
    private ActivityMainBinding ui;
    private ModelApplication model;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        ui = ActivityMainBinding.inflate(getLayoutInflater());
        setContentView(ui.getRoot());
        model = (ModelApplication) getApplication();
        ui.ParticipantList.setHasFixedSize(true);
        ui.ParticipantList.setAdapter(new ParticipantAdapter());
        RecyclerView.LayoutManager lm = new LinearLayoutManager(this, RecyclerView.VERTICAL, false);
        ui.ParticipantList.setLayoutManager(lm);
        ui.ParticipantList.addItemDecoration(new DividerItemDecoration(this, DividerItemDecoration.VERTICAL));
        ui.SumAutres.setText(model.getSumOperations("AUTRES") +"");
        ui.SumHebergement.setText(model.getSumOperations("HEBERGEMENT")+ "");
        ui.SumRestauration.setText(model.getSumOperations("RESTAURATION") +"");
        ui.SumLoisirs.setText(model.getSumOperations("LOISIRS") +"");
        ui.SumTransport.setText(model.getSumOperations("TRANSPORT") +"");
        List<Participant> participantsList= new ArrayList<>();
        for(int i = 0; i < model.getNbParticipants(); i++){
            participantsList.add(model.getParticipant(i));
        }
        ui.ParticipantList.setAdapter(new ParticipantAdapter(participantsList));
        Button btnParticipant =findViewById(R.id.add_participant);
        btnParticipant.setOnClickListener(new View.OnClickListener(){
            @Override
            public void onClick(View v){
                EditText et = findViewById(R.id.new_participant);
                try {
                    model.addParticipant(et.getText().toString());
                } catch (ModelApplication.ApplicationErrorException e) {
                    throw new RuntimeException(e);
                }
            }
        });
        refresh();
    }

    private void refresh() {
        model.computeBalance();
        ui.ParticipantList.getAdapter().notifyDataSetChanged();
    }

}